window.Gleam.initSearch([{"doc":"functx","title":"functx","content":"# functx\n\n[![Package Version](https://img.shields.io/hexpm/v/functx)](https://hex.pm/packages/functx)\n[![Hex Docs](https://img.shields.io/badge/hex-docs-ffaff3)](https://hexdocs.pm/functx/)\n![Erlang-compatible](https://img.shields.io/badge/target-erlang-a2003e)\n![JavaScript-compatible](https://img.shields.io/badge/target-javascript-f1e05a)\n\n![logo](logo.png)\n\nTiny Gleam caching Context for your functions\n\n```sh\ngleam add functx\n```\n\n```gleam\nimport functx.{type Ctx}\n\nfn nums(ctx: Ctx(Int)) {\n  // this function called only once during context\n\n  let #(n, _) = ctx\n\n  #([1, 2, 3, 4, 5, 6, 7, 8, 9, n], ctx)\n}\n\nfn nums_as_string(ctx) {\n  use ns, ctx &lt;- functx.call(ctx, nums)\n\n  let resp =\n    ns\n    |&gt; list.map(fn(n) { n |&gt; int.to_string })\n    |&gt; string.join(&quot;,&quot;)\n\n  #(resp, ctx)\n}\n\nfn nums_to_sum(ctx) {\n  use ns, ctx &lt;- functx.call(ctx, nums)\n\n  let resp = {\n    use acc, n &lt;- list.fold(ns, 0)\n    acc + n\n  }\n\n  #(resp, ctx)\n}\n\nfn nums_summary(ctx) {\n  use ns_str, ctx &lt;- functx.call(ctx, nums_as_string)\n  use ns_sum, ctx &lt;- functx.call(ctx, nums_to_sum)\n\n  let resp = &quot;Nums: &quot; &lt;&gt; ns_str &lt;&gt; &quot; Sum: &quot; &lt;&gt; ns_sum |&gt; int.to_string\n\n  #(resp, ctx)\n}\n\npub fn main() {\n  let resp =\n    10\n    |&gt; functx.make_ctx\n    |&gt; nums_summary\n\n  resp.0 // Nums: 1,2,3,4,5,6,7,8,9,10 Sum: 55\n}\n```\n\nFurther documentation can be found at &lt;https://hexdocs.pm/functx&gt;.\n\n## Development\n\n```sh\ngleam run   # Run the project\ngleam test  # Run the tests\ngleam shell # Run an Erlang shell\n```\n\n## See also\n\n- [context-fp](https://github.com/darky/context-fp) - Functional programming context for TypeScript\n- [context-fp-go](https://github.com/darky/context-fp-go) - Functional programming context for Golang\n","url":"index.html"},{"doc":"functx","title":"Ctx","content":"pub type Ctx(data) =\n  #(data, Dict(Dynamic, Dynamic))\n\n\nSynonyms:\nfunctx.Ctx\nfunctx Ctx","url":"functx.html#Ctx"},{"doc":"functx","title":"call","content":"pub fn call(\n  ctx: #(a, Dict(Dynamic, Dynamic)),\n  fun: fn(#(a, Dict(Dynamic, Dynamic))) -&gt;\n    #(b, #(a, Dict(Dynamic, Dynamic))),\n  cb: fn(b, #(a, Dict(Dynamic, Dynamic))) -&gt; c,\n) -&gt; c\n\nSynonyms:\nfunctx.call\nfunctx call","url":"functx.html#call"},{"doc":"functx","title":"make_ctx","content":"pub fn make_ctx(data: a) -&gt; #(a, Dict(b, c))\n\nSynonyms:\nfunctx.make_ctx\nfunctx make_ctx","url":"functx.html#make_ctx"},{"doc":"functx","title":"functx","content":"","url":"functx.html"}]);